***Analysis
**************

clear
use Data_Wiesli_Przepiorka
// set format of co-effients to three numbers after coma.
set cformat %9.3f 

*****************************************************************

*** Life satisfaction  index

alpha leisure-plainnoise, std item
* With casewise deletion of missings
alpha leisure-plainnoise, std item c

egen missing = rowmiss (leisure paths cycle publictr streets health securroa violence politpart finance employ social discrim basicsup living rentcosts affiliation landscape streetnoise neighbnoise plainnoise)
tab missing
egen sat2 = rowmean (leisure paths cycle publictr streets health securroa violence politpart finance employ social discrim basicsup living rentcosts affiliation landscape streetnoise neighbnoise plainnoise) if missing <= 6
label variable sat2 "index of satisfaction"

*****************************************************************

*** Construction of indicator for resource use with vignette variables about lifestyles

gen tmp = lsA + lsB + lsC
tab tmp
drop tmp

gen C = lsC 
gen B = lsA  
gen A = lsB

replace C = . if lsA + lsB + lsC<4
replace B = . if lsA + lsB + lsC<4
replace A = . if lsA + lsB + lsC<4

gen BC = B-C // A is the lifestyle with middle high resource use and will be excluded.  

gen BC2 = BC+11 

recode BC2 (1=21) (2=20) (3=19) (4=18) (5=17) (6=16) (7=15) (8=14) (9=13) (10=12) (11=11) (12=10) (13=9) (14=8) (15=7) (16=6) (17=5) (18=4) (19=3) (20=2) (21=1), gen (RVls) 
label variable RVls "index for reosurce use"

gen newmiss = lsC + lsA + lsB<4
label variable newmiss "exclusion of cases below 4"

// Generate age squared to account for u-shaped relation with satisfaction
gen age2 = age*age //age and satisfaction correlates reversed u-shaped.
 label variable age2 "age squared"
*****************************************************************

*** Testing the validity of the proxy variable for resource use

//The CO2 footprint is right-skewed. Therefore the following log-transformation.
gen lco2foot = log(co2footprint)
label variable lco2foot "log transformed var of CO2 footprint"

//Spearman correlation and OLS-regression to validate the indicator resource use with carbon footprint: table 1 
spearman RVls lco2foot
reg RVls lco2foot

pwcorr RVls houseincom lco2foot, obs list sig
egen tmp = rowmiss(RVls houseincom lco2foot)
replace tmp = 1 if tmp > 0
reg lco2foot age ge ki houseincom eduyears if tmp==0
eststo: reg RVls lco2foot age ge ki houseincom eduyears if tmp==0
esttab using table1.csv, b(a3) se(a3) ar2(a3) replace wide plain star
eststo clear
*****************************************************************

***Creating factors of infrastructure and finanical situation in order to imupute herafter and to use in the analysis of the appendix B

//Creating index of satisfaction with infrastructure
alpha leisure paths cycle publictr streets basicsup, std item detail

global V1 leisure paths cycle publictr streets health securroa violence politpart finance employ social discrim basicsup living rentcosts affiliation landscape streetnoise plainnoise neighbnoise

//Principle axis factoring with non-orthogonal rotation
factor $V1, ipf factor(5)
   rotate, promax blanks(.4)
   estat common
   est store F1

estat kmo

//Creating satisfaction with personal economic and personal situation in general
global V2 finance employ living rentcosts leisure paths cycle publictr streets basicsup

alpha finance employ living rentcosts, std item detail

//Principle axis factoring with non-orthogonal rotation
factor $V2, ipf factor(2)
   rotate, promax blanks(.4)
   estat common
   est store F2
estat kmo

rename _est_F1 F1 //Infrastructure
rename _est_F2 F2 //Financial situation

*****************************************************************

*** Testing the correlation of the satisfaction variable and the index of satisfaction

spearman satisfaction sat2
spearman satisfaction F1 
spearman satisfaction F2 

reg satisfaction sat2 
reg satisfaction sat2 age ge houseincom eduyears pa if tmp==0


pwcorr satisfaction sat2, obs list sig
pwcorr F1 sat2, obs list sig
pwcorr F2 sat2, obs list sig
drop tmp
*****************************************************************

***Descriptive statistics of the variables included in regression-models: Table 2

gen tmp = region != 2
tabstat satisfaction RVls age ge housing eduyears houseincom pa ki yrplace enviconc2, s(mean sd count) by(tmp) columns(s) long
drop tmp

*****************************************************************

*** multiple impuation (see sub-section "Dealing with Missing Cases" in the manuscript)

//Examine the number and proportion of missing values among the variables of interest. 
misstable summarize satisfaction sat2 F1 F2 RVls age ge housing houseincom eduyears pa ki enviconc2 yrplace place

//excluding cases that were set missing in the process of creating the DV.
misstable summarize satisfaction sat2 F1 F2 RVls age ge housing houseincom eduyears pa ki enviconc2 yrplace place if !newmiss & place !=. 
mdesc satisfaction sat2 F1 F2 RVls age ge housing houseincom eduyears pa ki enviconc2 yrplace place

//The following tells Stata how the multiplied imputed data is to be stored once the imputation has been completed.
mi set mlong 

// The following tells Stata which variables have missing values that will be imputed.
mi register imputed satisfaction sat2 RVls houseincom eduyears enviconc2 yrplace F1 F2 age age2 ge housing pa ki place

egen tmp = rowmiss(ge housing pa ki place)
gen keepmiss = tmp > 0 | newmiss
drop tmp 

misstable summarize satisfaction sat2 F1 F2 RVls age ge housing houseincom eduyears pa ki enviconc2 yrplace place if !keepmiss

// The following performs the imputation of missing values in houseincome.
mi impute mvn satisfaction sat2 RVls houseincom eduyears enviconc2 yrplace F1 F2 age age2 ge housing pa ki place if !keepmiss, add(30) rseed(1234) force 

su RVls houseincom eduyears enviconc2 yrplace, d

//log transformation of RVls
//this is done after mi because 
//RVls and lRVls are too highly correlated
//First transform 16 cases with neg values
//with a value close to zero.
su RVls if RVls > 0 & RVls < 1
replace RVls = 0.01 if RVls < 0
gen lRVls = log(RVls)
label variable lRVls "log tranformed index for resource use"
*****************************************************************

*** HP 1a: People’s self-reported satisfaction correlates positively with their resource use. 

// Simple OLS regression: table 3 M1 
mi est: reg satisfaction RVls if !keepmiss, cluster(place)
mibeta satisfaction RVls if !keepmiss, cluster(place)
//mibeta sat RVls if miss, cluster(place) 

// Multiple OLS regression: table 3 M2
mi est: reg satisfaction RVls age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place) 
mibeta satisfaction RVls age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place) 
****************************************************************

*** HP 1b: The relation between people’s self-reported satisfaction and their resource use is increasing at a decreasing rate. Funktionale Form auch im negativen 

//Simple Regression: table 3 M3 with log.
mi est: reg satisfaction lRVls if !keepmiss, cluster(place)
mibeta satisfaction lRVls if !keepmiss, cluster(place) 

//Multiple Regression: table 3 M4 with log.
mi est: reg satisfaction lRVls age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place) 
mibeta satisfaction lRVls age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)  
*****************************************************************

*** HP 2a: The resource use of people living in parks are smaller and their self-reported satisfactions are higher than for people living in comparable, non-park regions.

//creating dummy variable for park/non-park variable 
recode region (2 = 0) (1 3 4 = 1), generate(bynreg) //1 will be the parks, 0 will be non-park-regions

//Simple regression satisfaction
mi est: reg satisfaction ib0.bynreg if !keepmiss, cluster(place) 
mibeta satisfaction ib0.bynreg if !keepmiss, cluster(place) 

//multiple regression satisfaction: table 4 M5
mi est: reg satisfaction ib0.bynreg age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place) 
mibeta satisfaction ib0.bynreg age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)   //region ist interaktions, Steigung ist interaktion, Steigungen unterschieden sich nicht weil Interaktionen ishc nicht unterscheiden 

//Simple regression resource use
mi est: reg RVls ib0.bynreg if !keepmiss, cluster(place) 
mibeta RVls ib0.bynreg if !keepmiss, cluster(place)  

//multiple regression resource use: table 4 M7
mi est: reg RVls ib0.bynreg age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)  
mibeta RVls ib0.bynreg age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)  
*****************************************************************

*** HP 2b: The positive correlation between self-reported satisfaction and resource use will be weaker for park inhabitants than for individuals living outside of parks
  
//Simple regression 
mi est: reg satisfaction RVls ib0.bynreg c.RVls#ib0.bynreg if !keepmiss, cluster(place) 
mibeta satisfaction RVls ib0.bynreg c.RVls#ib0.bynreg if !keepmiss, cluster(place)    //we include interaction term and thus multiplicate the IP var with the regions. ib0. treats 0 as base, c. to treat as continuous variable. Otherwise stata assumes them as categorcial. 

//Multiple regression: table 4 M6
mi est: reg satisfaction RVls ib0.bynreg c.RVls#ib0.bynreg age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)  
mibeta satisfaction RVls ib0.bynreg c.RVls#ib0.bynreg age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)

mibeta satisfaction RVls ib0.bynreg age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)  										
						
*****************************************************************

*** HP 3a: The resource use of the individuals in the UNESCO Biosphere Entlebuch is lower and the satisfaction is higher than in the Nature Parks Gantrisch and Jurapark Aargau.
		
//Simple regression: table 5 M8 with interaction term resource use with the four regions
mi est: reg RVls ib4.region if !keepmiss, cluster(place) 
mibeta RVls ib4.region if !keepmiss, cluster(place)   //region 2 control region is the base

//Simple regression: table 5 M9 with interaction term satisfaction with the four regions
mi est: reg satisfaction ib4.region if !keepmiss, cluster(place) 
mibeta satisfaction ib4.region if !keepmiss, cluster(place)   //region 2 control region is the base
	
*****************************************************************

*** HP 3b: The strength of the positive correlation between satisfaction and the resource use is moderated by the age of the parks. 

//Simple regression: table 5 M10 with interaction term resource use with the four regions
mi est: reg satisfaction RVls ib4.region c.RVls#ib4.region if !keepmiss, cluster(place) 
mibeta satisfaction RVls ib4.region c.RVls#ib4.region if !keepmiss, cluster(place)   //region 2 control region is the base

//Multiple regression: table 5 M11 with interaction term resource use with the four regions
mi est: reg satisfaction RVls ib4.region c.RVls#ib4.region age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)
mibeta satisfaction RVls ib4.region c.RVls#ib4.region age age2 ge housing houseincom eduyears pa ki enviconc2 yrplace if !keepmiss, cluster(place)  
*****************************************************************

*** Does environmental awareness differ between park and non-park regions?
reg enviconc2 ib0.bynreg if !keepmiss, cluster(place)  
sum enviconc2 if bynreg == 0
sum enviconc2 if bynreg == 1

**********************************************************************************************************************************End of do-file
